@@ -1,6 +1,13 @@
+'''
+@file       :   IsPycharmRum.py
+@author     :   shiboxuan
+@email      :   shiboxuan02@playcrab.com
+@date       :   2020-06-10
+@version    :   0.7
+'''
+
 from functools import wraps
 import os
-
 class IsPycharmRun:
     def __init__(self, deviceUrl, logDir):
         self.deviceUrl = deviceUrl
@@ -8,16 +15,14 @@ class IsPycharmRun:
 
     def __call__(self, func):
         @wraps(func)
-        def wrapped_function(baseDir):
+        def wrapped_function(*args):
             if self.isPycharmRun():
                 print(func.__name__ + " was called")
-                return func(basedir=baseDir, devices=self.deviceUrl, logdir=self.logDir)
+                return func(basedir=args[0], devices=self.deviceUrl, logdir=self.logDir)
+            else:
+                return func(*args)
         return wrapped_function
 
     def isPycharmRun(self):
         isRunningInPyCharm = "PYCHARM_HOSTED" in os.environ
         return isRunningInPyCharm
-
-
-if __name__ == "__main__":
-    a = IsPycharmRun("MasterTable")
\ No newline at end of file
